@@ -177,7 +177,7 @@ function decode_mime_string ($string) {
 
    echo "<HR>\n";
 
-   $body = imap_fetchbody($mbox, $msg, 1);
+   $body = htmlspecialchars(imap_fetchbody($mbox, $msg, 1));
 
    echo "<TABLE><TR><TD><TABLE BORDER>\n";
    echo "<TR><TH>Msg #</TH><TD ALIGN=CENTER>$msg</TD><TH COLSPAN=2>\n";
